Learn R Programming

focalCall (version 1.6.0)

BierkensCNA: Cervical cancer arrayCGH data

Description

Example dataset with arrayCGH data of cervical pre-cancer lesions. OF NOTE: this set contains only 8 samples from the data and only the complete probeset for chromosome 2. Complete dataset is available from GEO (GSE34575).

Usage

BierkensCNA

Arguments

Value

Format

This dataset contain three files:
CGHset
a CGHcall object containing 8 cervical pre-curses cancer lesions. These samples were taken from Bierkens et al. 2013 and available under GEO accession number GSE34575.
CNVset
a bed file with CNV locations as provided by http://dgv.tcag.ca/.
calls_focals
Complete results file after running focalCall on the example data from Bierkens et al. 2013.
CGHset: A CGHcall object containing the following 8 samples:
hgCIN.2.10_16
high-grade Cervical Intra-epithelial Neoplasia sample: hgCIN.2.10_16.
hgCIN.2.13_16
high-grade Cervical Intra-epithelial Neoplasia sample: hgCIN.2.13_16.
hgCIN.2.8_31
high-grade Cervical Intra-epithelial Neoplasia sample: hgCIN.2.8_31.
hgCIN.2.16_31
high-grade Cervical Intra-epithelial Neoplasia sample: hgCIN.2.16_31.
CIN3.1.2_16
Cervical Intra-epithelial Neoplasia sample: CIN3.1.2_16.
hgCIN.2.4_16
high-grade Cervical Intra-epithelial Neoplasia sample: hgCIN.2.4_16.
CIN3.1.8_16
Cervical Intra-epithelial Neoplasia sample: CIN3.1.8_16.
hgCIN.2.19_58
high-grade Cervical Intra-epithelial Neoplasia sample: hgCIN.2.19_58.
CNVset: A bed file containing the following columns:
CNV ID
Identification ID for copy number variation (CNV)
start
Basepair position that indicates start of CNV
end
Basepair position that indicates end of CNV
calls_focals: results file after running focalCall on the samples described above:
calls_focals
results file of class cghCall

Bierkens, M., Krijgsman, O., Wilting, S.M., Bosch, L., Jaspers, A., Meijer, G.A., Meijer, C.J., Snijders, P.J., Ylstra, B., Steenbergen, R.D. (2013). Focal aberrations indicate EYA2 and hsa-miR-375 as oncogene and tumor suppressor in cervical carcinogenesis. Genes Chromosomes Cancer 52,56-68.

Examples

Run this code
# Load the data file
data(BierkensCNA)

Run the code above in your browser using DataLab